ADS1256 - Heros Devices 0.11.1 documentation

Skip to content
Back to top
View this page

# ADS1256

From: Texas Instruments

Class: `herosdevices.hardware.texas_instruments.ads1256.ADS1256`

Driver Quality Index: alpha

Interfacing the ADS1256 SPI ADC (as e.g. used on the Waveshare high-precision AD-DA board).

Arguments

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.texas_instruments.ads1256.ADS1256` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
spi_bus | <class ‘int’> | 0 | Number of the SPI bus the ADS1256 is attached to
spi_device | <class ‘int’> | 0 | Device number at the SPI bus the ADS1256 is attached to
drdy_pin | <class ‘int’> | 17 | pin number of the data ready pin
rst_pin | int | None | None | pin number of the reset pin
spi |  | None | optional spidev device. If this is given, spi_bus and spi_device are ignored.
gpio_device | <class ‘str’> | /dev/gpiochip0 | full path to kernel character device that holds the needed gpios. Typically “/dev/gpiochip0”
default_gain | <enum ‘ADS1256_GAIN’> | ADS1256_GAIN.GAIN_1 | default gain to set when initializing the device
default_drate | <enum ‘ADS1256_DRATE’> | ADS1256_DRATE.DRATE_30000SPS | default data rate to set when initializing the device

Example JSON for BOSS

The following JSON strings can be used to start a HERO device representation of `ADS1256` using BOSS.

    {
        "_id": "my_ADS1256",
        "classname": "herosdevices.hardware.texas_instruments.ads1256.ADS1256",
        "arguments": {
            "spi_bus": 0,
            "spi_device": 0,
            "drdy_pin": 17,
            "rst_pin": null,
            "spi": null,
            "gpio_device": "/dev/gpiochip0",
            "default_gain": 0,
            "default_drate": 240
        }
    }

generated from signature

Inheritance